/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: scoutteam@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package swagger

import (
	"net/url"
	"os"
	"io/ioutil"
	"encoding/json"
	"fmt"
	"strings"
)

type FileManagementApi struct {
	Configuration Configuration
}

func NewFileManagementApi() *FileManagementApi {
	configuration := NewConfiguration()
	return &FileManagementApi{
		Configuration: *configuration,
	}
}

func NewFileManagementApiWithBasePath(basePath string) *FileManagementApi {
	configuration := NewConfiguration()
	configuration.BasePath = basePath

	return &FileManagementApi{
		Configuration: *configuration,
	}
}

/**
 * Delete a single file
 * Unstages the file with the provided ID. The file must have a STAGED status; if the file isn&#39;t STAGED, returns a 409 status. If the file isn&#39;t found, this is a no-op.
 *
 * @param fileId The unique identifier of the file
 * @return *BaseResponseOfstring
 */
func (a FileManagementApi) DeleteFileUsingDELETE(fileId string) (*BaseResponseOfstring, *APIResponse, error) {

	var httpMethod = "Delete"
	// create path and map variables
	path := a.Configuration.BasePath + "/api/v1/file/{fileId}"
	path = strings.Replace(path, "{"+"fileId"+"}", fmt.Sprintf("%v", fileId), -1)


	headerParams := make(map[string]string)
	queryParams := url.Values{}
	formParams := make(map[string]string)
	var postBody interface{}
	var fileName string
	var fileBytes []byte
	// authentication '(oauth)' required
	// oauth required
	if a.Configuration.AccessToken != ""{
		headerParams["Authorization"] =  "Bearer " + a.Configuration.AccessToken
	}
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		headerParams[key] = a.Configuration.DefaultHeader[key]
	}


	// to determine the Content-Type header
	localVarHttpContentTypes := []string{ "application/json",  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		headerParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
	}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		headerParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new(BaseResponseOfstring)
	httpResponse, err := a.Configuration.APIClient.CallAPI(path, httpMethod, postBody, headerParams, queryParams, formParams, fileName, fileBytes)
	if err != nil {
		return successPayload, NewAPIResponse(httpResponse.RawResponse), err
	}
	err = json.Unmarshal(httpResponse.Body(), &successPayload)
	return successPayload, NewAPIResponse(httpResponse.RawResponse), err
}

/**
 * Download a single file
 * Returns a file with the provided ID, which points to a file meta ID.
 *
 * @param fileId The unique identifier of the file
 * @return *string
 */
func (a FileManagementApi) DownloadFileUsingGET(fileId string) (*string, *APIResponse, error) {

	var httpMethod = "Get"
	// create path and map variables
	path := a.Configuration.BasePath + "/api/v1/file/{fileId}/download"
	path = strings.Replace(path, "{"+"fileId"+"}", fmt.Sprintf("%v", fileId), -1)


	headerParams := make(map[string]string)
	queryParams := url.Values{}
	formParams := make(map[string]string)
	var postBody interface{}
	var fileName string
	var fileBytes []byte
	// authentication '(oauth)' required
	// oauth required
	if a.Configuration.AccessToken != ""{
		headerParams["Authorization"] =  "Bearer " + a.Configuration.AccessToken
	}
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		headerParams[key] = a.Configuration.DefaultHeader[key]
	}


	// to determine the Content-Type header
	localVarHttpContentTypes := []string{ "application/json",  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		headerParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"*_/_*",
	}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		headerParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new(string)
	httpResponse, err := a.Configuration.APIClient.CallAPI(path, httpMethod, postBody, headerParams, queryParams, formParams, fileName, fileBytes)
	if err != nil {
		return successPayload, NewAPIResponse(httpResponse.RawResponse), err
	}
	err = json.Unmarshal(httpResponse.Body(), &successPayload)
	return successPayload, NewAPIResponse(httpResponse.RawResponse), err
}

/**
 * Export a file to spreadsheets
 * Exports the file ID identified in the path to the spreadsheet identified by the provided URL. If the URL string is empty, creates and returns a new spreadsheet and its sheet IDs.
 *
 * @param fileId The unique identifier of the file
 * @param exportFileDto The representation of the file to export
 * @return *BaseResponseOfSpreadsheetInfoDto
 */
func (a FileManagementApi) ExportFileToSpreadsheetsUsingPOST(fileId string, exportFileDto ExportFileDto) (*BaseResponseOfSpreadsheetInfoDto, *APIResponse, error) {

	var httpMethod = "Post"
	// create path and map variables
	path := a.Configuration.BasePath + "/api/v1/file/{fileId}/export"
	path = strings.Replace(path, "{"+"fileId"+"}", fmt.Sprintf("%v", fileId), -1)


	headerParams := make(map[string]string)
	queryParams := url.Values{}
	formParams := make(map[string]string)
	var postBody interface{}
	var fileName string
	var fileBytes []byte
	// authentication '(oauth)' required
	// oauth required
	if a.Configuration.AccessToken != ""{
		headerParams["Authorization"] =  "Bearer " + a.Configuration.AccessToken
	}
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		headerParams[key] = a.Configuration.DefaultHeader[key]
	}


	// to determine the Content-Type header
	localVarHttpContentTypes := []string{ "application/json",  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		headerParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
	}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		headerParams["Accept"] = localVarHttpHeaderAccept
	}
	// body params
	postBody = &exportFileDto

	var successPayload = new(BaseResponseOfSpreadsheetInfoDto)
	httpResponse, err := a.Configuration.APIClient.CallAPI(path, httpMethod, postBody, headerParams, queryParams, formParams, fileName, fileBytes)
	if err != nil {
		return successPayload, NewAPIResponse(httpResponse.RawResponse), err
	}
	err = json.Unmarshal(httpResponse.Body(), &successPayload)
	return successPayload, NewAPIResponse(httpResponse.RawResponse), err
}

/**
 * Retrieve errors
 * Returns a paged list of operation errors during the upload, import, or tagging processes for the provided file ID, if they exist. This list is immutable and may be empty if no errors have occurred. If errors exist we recommend fixing them and reimporting your file
 *
 * @param fileId The unique identifier of the file
 * @param limit The number of errors to return, from 1 to 50; by default, 50
 * @param cursor A paging cursor; if included, &#x60;limit&#x60; is ignored
 * @param offset The item to start with on the page, greater than or equal to 0; by default, 0
 * @return *PagedResponseOfImportErrorDto
 */
func (a FileManagementApi) GetErrorsUsingGET(fileId string, limit int32, cursor string, offset int64) (*PagedResponseOfImportErrorDto, *APIResponse, error) {

	var httpMethod = "Get"
	// create path and map variables
	path := a.Configuration.BasePath + "/api/v1/file/{fileId}/error"
	path = strings.Replace(path, "{"+"fileId"+"}", fmt.Sprintf("%v", fileId), -1)


	headerParams := make(map[string]string)
	queryParams := url.Values{}
	formParams := make(map[string]string)
	var postBody interface{}
	var fileName string
	var fileBytes []byte
	// authentication '(oauth)' required
	// oauth required
	if a.Configuration.AccessToken != ""{
		headerParams["Authorization"] =  "Bearer " + a.Configuration.AccessToken
	}
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		headerParams[key] = a.Configuration.DefaultHeader[key]
	}
		queryParams.Add("limit", a.Configuration.APIClient.ParameterToString(limit, ""))
			queryParams.Add("cursor", a.Configuration.APIClient.ParameterToString(cursor, ""))
			queryParams.Add("offset", a.Configuration.APIClient.ParameterToString(offset, ""))
	

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{ "application/json",  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		headerParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
	}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		headerParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new(PagedResponseOfImportErrorDto)
	httpResponse, err := a.Configuration.APIClient.CallAPI(path, httpMethod, postBody, headerParams, queryParams, formParams, fileName, fileBytes)
	if err != nil {
		return successPayload, NewAPIResponse(httpResponse.RawResponse), err
	}
	err = json.Unmarshal(httpResponse.Body(), &successPayload)
	return successPayload, NewAPIResponse(httpResponse.RawResponse), err
}

/**
 * Retrieve a single file
 * Returns the file meta that matches the provided ID, or a 404 if an associated file can&#39;t be found.
 *
 * @param fileId The unique identifier of the file
 * @return *BaseResponseOfFileMetaDto
 */
func (a FileManagementApi) GetFileUsingGET(fileId string) (*BaseResponseOfFileMetaDto, *APIResponse, error) {

	var httpMethod = "Get"
	// create path and map variables
	path := a.Configuration.BasePath + "/api/v1/file/{fileId}"
	path = strings.Replace(path, "{"+"fileId"+"}", fmt.Sprintf("%v", fileId), -1)


	headerParams := make(map[string]string)
	queryParams := url.Values{}
	formParams := make(map[string]string)
	var postBody interface{}
	var fileName string
	var fileBytes []byte
	// authentication '(oauth)' required
	// oauth required
	if a.Configuration.AccessToken != ""{
		headerParams["Authorization"] =  "Bearer " + a.Configuration.AccessToken
	}
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		headerParams[key] = a.Configuration.DefaultHeader[key]
	}


	// to determine the Content-Type header
	localVarHttpContentTypes := []string{ "application/json",  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		headerParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
	}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		headerParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new(BaseResponseOfFileMetaDto)
	httpResponse, err := a.Configuration.APIClient.CallAPI(path, httpMethod, postBody, headerParams, queryParams, formParams, fileName, fileBytes)
	if err != nil {
		return successPayload, NewAPIResponse(httpResponse.RawResponse), err
	}
	err = json.Unmarshal(httpResponse.Body(), &successPayload)
	return successPayload, NewAPIResponse(httpResponse.RawResponse), err
}

/**
 * Retrieve a list of files
 * Returns a paged list of all files associated with the provided table ID, as well as metadata associated with each file.
 *
 * @param tableId The unique table identifier associated with this file
 * @param limit The number of files to return, from 1 to 1000; by default, 1000
 * @param cursor A paging cursor; if included, &#x60;limit&#x60; is ignored
 * @param offset The item to start with on the page, greater than or equal to 0; by default, 0
 * @param sortOrder The sort order for the files being returned
 * @param sortBy The column to use the sort order on
 * @param searchText The text to filter the results upon; matching the file name
 * @return *PagedResponseOfFileMetaDto
 */
func (a FileManagementApi) GetFilesUsingGET(tableId string, limit int32, cursor string, offset int64, sortOrder string, sortBy string, searchText string) (*PagedResponseOfFileMetaDto, *APIResponse, error) {

	var httpMethod = "Get"
	// create path and map variables
	path := a.Configuration.BasePath + "/api/v1/file"


	headerParams := make(map[string]string)
	queryParams := url.Values{}
	formParams := make(map[string]string)
	var postBody interface{}
	var fileName string
	var fileBytes []byte
	// authentication '(oauth)' required
	// oauth required
	if a.Configuration.AccessToken != ""{
		headerParams["Authorization"] =  "Bearer " + a.Configuration.AccessToken
	}
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		headerParams[key] = a.Configuration.DefaultHeader[key]
	}
		queryParams.Add("tableId", a.Configuration.APIClient.ParameterToString(tableId, ""))
			queryParams.Add("limit", a.Configuration.APIClient.ParameterToString(limit, ""))
			queryParams.Add("cursor", a.Configuration.APIClient.ParameterToString(cursor, ""))
			queryParams.Add("offset", a.Configuration.APIClient.ParameterToString(offset, ""))
			queryParams.Add("sortOrder", a.Configuration.APIClient.ParameterToString(sortOrder, ""))
			queryParams.Add("sortBy", a.Configuration.APIClient.ParameterToString(sortBy, ""))
			queryParams.Add("searchText", a.Configuration.APIClient.ParameterToString(searchText, ""))
	

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{ "application/json",  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		headerParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
	}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		headerParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new(PagedResponseOfFileMetaDto)
	httpResponse, err := a.Configuration.APIClient.CallAPI(path, httpMethod, postBody, headerParams, queryParams, formParams, fileName, fileBytes)
	if err != nil {
		return successPayload, NewAPIResponse(httpResponse.RawResponse), err
	}
	err = json.Unmarshal(httpResponse.Body(), &successPayload)
	return successPayload, NewAPIResponse(httpResponse.RawResponse), err
}

/**
 * Upload a single file
 * Accepts CSV, TSV, or JSON files, or a ZIP file that contains a single CSV, TSV, or JSON file. If a ZIP, it must contain a CSV, TSV, or JSON file, and the name of the CSV, TSV, or JSON file is also used with the imported file. Downloading this file again downloads the source. Note that all files uploaded must have a .csv, .tsv, or .json extension. JSON files are expected to have a single JSON record per line; a JSON file is a series of JSON objects delimited by a newline character.
 *
 * @param tableId The unique table identifier associated with this file
 * @param file The physical file to upload
 * @param name No longer in use, here to ensure backwards compatibility
 * @param url No longer in use, here to ensure backwards compatibility
 * @param source The data source to associate with the file, no more than 255 characters. This field is not in use; it only keeps track of the source
 * @param delimiter The character to use as a delimiter within the file to separate one field from another.  The default is comma
 * @return *BaseResponseOfFileMetaDto
 */
func (a FileManagementApi) UploadFileUsingPOST(tableId string, file *os.File, name string, url string, source string, delimiter string) (*BaseResponseOfFileMetaDto, *APIResponse, error) {

	var httpMethod = "Post"
	// create path and map variables
	path := a.Configuration.BasePath + "/api/v1/file"


	headerParams := make(map[string]string)
	queryParams := url.Values{}
	formParams := make(map[string]string)
	var postBody interface{}
	var fileName string
	var fileBytes []byte
	// authentication '(oauth)' required
	// oauth required
	if a.Configuration.AccessToken != ""{
		headerParams["Authorization"] =  "Bearer " + a.Configuration.AccessToken
	}
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		headerParams[key] = a.Configuration.DefaultHeader[key]
	}


	// to determine the Content-Type header
	localVarHttpContentTypes := []string{ "multipart/form-data",  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		headerParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
	}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		headerParams["Accept"] = localVarHttpHeaderAccept
	}

	fbs, _ := ioutil.ReadAll(file)
	fileBytes = fbs
	fileName = file.Name()

	formParams["tableId"] = tableId
	formParams["name"] = name
	formParams["url"] = url
	formParams["source"] = source
	formParams["delimiter"] = delimiter
	var successPayload = new(BaseResponseOfFileMetaDto)
	httpResponse, err := a.Configuration.APIClient.CallAPI(path, httpMethod, postBody, headerParams, queryParams, formParams, fileName, fileBytes)
	if err != nil {
		return successPayload, NewAPIResponse(httpResponse.RawResponse), err
	}
	err = json.Unmarshal(httpResponse.Body(), &successPayload)
	return successPayload, NewAPIResponse(httpResponse.RawResponse), err
}

/**
 * Validate whether a file with the filename can be uploaded to the table
 * If the filename is valid, this returns 200. If the table already has a file with the same name, this returns 409. If the user isn&#39;t allowed to read the table, or if the table isn&#39;t found, this returns 404.
 *
 * @param tableId The ID of the table to upload the file to
 * @param filename The name of the file to upload
 * @return *BaseResponseOfstring
 */
func (a FileManagementApi) ValidateFilenameUsingGET(tableId string, filename string) (*BaseResponseOfstring, *APIResponse, error) {

	var httpMethod = "Get"
	// create path and map variables
	path := a.Configuration.BasePath + "/api/v1/file/validateName"


	headerParams := make(map[string]string)
	queryParams := url.Values{}
	formParams := make(map[string]string)
	var postBody interface{}
	var fileName string
	var fileBytes []byte
	// authentication '(oauth)' required
	// oauth required
	if a.Configuration.AccessToken != ""{
		headerParams["Authorization"] =  "Bearer " + a.Configuration.AccessToken
	}
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		headerParams[key] = a.Configuration.DefaultHeader[key]
	}
		queryParams.Add("tableId", a.Configuration.APIClient.ParameterToString(tableId, ""))
			queryParams.Add("filename", a.Configuration.APIClient.ParameterToString(filename, ""))
	

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{ "application/json",  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		headerParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
	}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		headerParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new(BaseResponseOfstring)
	httpResponse, err := a.Configuration.APIClient.CallAPI(path, httpMethod, postBody, headerParams, queryParams, formParams, fileName, fileBytes)
	if err != nil {
		return successPayload, NewAPIResponse(httpResponse.RawResponse), err
	}
	err = json.Unmarshal(httpResponse.Body(), &successPayload)
	return successPayload, NewAPIResponse(httpResponse.RawResponse), err
}

